Implementations of VCS we can interact with
Structs
Enums
Traits
- Vcs
- A wrapper around accessing different values from a VCS config
Functions
- read_
toml - Find and read the correct toml config
- resolve_
commit_ message_ path - Resolve the path to the file containing the commit log message.