Module mit

Module mit 

Interactions relating to reading and setting authors

Re-exports

pub use cmd::get_config_rotation::get_config_rotation;
pub use cmd::rotate_authors::rotate_authors;
pub use cmd::set_config_rotation::set_config_rotation;
pub use lib::rotation_option::RotationOption;

Modules

cmd
Mit commands
lib
Domain objects for author options

Structs

Author
An author that might be developing
Authors
Collection of authors
GenericArgs
A generic structure to pass around details needed to get authors

Enums

AuthorState
The state of the authors config

Traits

AuthorArgs
From a cli args, get the author configuration

Functions

get_authors
Get authors from config
get_commit_coauthor_configuration
Get the co-authors that are currently defined for this vcs config source
set_commit_authors
Errors
set_config_authors
Errors